# Wikjs-API-Wrapper
A basic API wrapper for wikijs written in Python



PYPI versions aren't available yet.


# Installation from repo
```
$ git clone https://github.com/WERTBON1789/wikjs-api-wrapper
$ cd wikijs-api-wrapper
$ pip install .
```

# Run examples

First, you need to copy examples/example.setting.json to examples/settings.json
and add your hostname and token for wikijs

To run scripts from the examples directory you can either install the package, install it in a venv, or to run them as modules without installing:

```
$ python -m examples.pages_list
```
